@@ -120,6 +120,13 @@ class SignalBoxClient:
             return r.json()
         else:
             raise SignalBoxException(r.text)
+    
+    def get_offers(self, experimentId: str):
+        r = get(f'{self.base_url}/api/experiments/{experimentId}/offers', self.access_token)
+        if r.ok:
+            return r.json()
+        else:
+            raise SignalBoxException(r.text)
 
     def recommend_offer(self, experimentId: str, commonUserId: str, features: dict = None):
         json_params = {
