@@ -21,6 +21,10 @@ experiment_id = experiment['id']
 get_experiment_response = test_client.get_experiment(experiment_id)
 print('\nPrinting get_experiment test response: ', get_experiment_response)
 
+offers_in_experiment = test_client.get_offers(experiment_id)
+assert offers_in_experiment is not None
+assert len(offers_in_experiment) > 0
+
 print('\nPrinting create_offer test response: ', offer)
 print('\nPrinting create_experiment test response: ', experiment)
 
